@@ -5,8 +5,9 @@ from logging import getLogger
 from aiohttp.client_exceptions import WSServerHandshakeError
 
 from ..api import WebSocketClient
-from ..api.models.v2 import Title, Schedule, YouTubeData, Team, SeedStats, Include, DescriptionType, PlayListType
-
+from ..api.models.v2 import Title, Schedule, YouTubeData, Team, SeedStats, Include, DescriptionType, PlayListType, RSSType
+from ..api.dispatch import Event
+from ..api.error import NoArgumentsError
 
 log = getLogger("anilibria.client")
 __all__ = ["AniLibriaClient"]
@@ -51,11 +52,11 @@ class AniLibriaClient:
         :param data: Дополнительные данные.
         """
         if coro is not None:
-            self._websocket._listener.add_event(name or coro.__name__, {"coro": coro, "data": data})
+            self._websocket.dispatcher.add_event(name or coro.__name__, Event(coro=coro, data=data))
             return coro
 
         def decorator(coro: Coroutine):
-            self._websocket._listener.add_event(name or coro.__name__, {"coro": coro, "data": data})
+            self._websocket.dispatcher.add_event(name or coro.__name__, Event(coro=coro, data=data))
             return coro
 
         return decorator
@@ -131,6 +132,9 @@ class AniLibriaClient:
         :return: Объект тайтла
         :rtype: Title
         """
+        if id is None and code is None:
+            raise NoArgumentsError("id", "code")
+
         data = await self._websocket._http.v2.get_title(
             id=id,
             code=code,
@@ -166,6 +170,9 @@ class AniLibriaClient:
         :return: Список тайтлов
         :rtype: List[Title]
         """
+        if id_list is None and code_list is None:
+            raise NoArgumentsError("id_list", "code_list")
+
         data = await self._websocket._http.v2.get_titles(
             id_list=id_list,
             code_list=code_list,
@@ -455,12 +462,12 @@ class AniLibriaClient:
 
     async def get_rss(
         self,
-        rss_type: Optional[str] = None,
+        rss_type: Optional[RSSType] = None,
         session_id: Optional[str] = None,
         since: Optional[int] = None,
         after: Optional[int] = None,
         limit: Optional[int] = None,
-    ) -> str:  # ? str?
+    ) -> str:
         """
         Возвращает список обновлений на сайте в одном из форматов RSS ленты.
 
@@ -484,7 +491,7 @@ class AniLibriaClient:
     async def search_titles(
         self,
         search: Optional[List[str]] = None,
-        year: Optional[List[str]] = None,
+        year: Optional[List[Union[str, int]]] = None,
         season_code: Optional[List[str]] = None,
         genres: Optional[List[str]] = None,
         voice: Optional[List[str]] = None,
